#ifdef EXPORT_DECLSPEC
#define DECLSPEC extern "C" __declspec(dllexport) int __stdcall
#else
#define DECLSPEC extern "C" __declspec(dllimport) int __stdcall
#endif

////////////////////////////////////////////////////////////
// Return code
////////////////////////////////////////////////////////////

#define LE_FAIL		0
#define LE_SUCCESS	1

////////////////////////////////////////////////////////////
// Structure for setting table data
////////////////////////////////////////////////////////////

struct LE_TABLE_ELEMENT
{
	int length;
	BYTE character[16384];
	BYTE flag[16384];
};

struct LE_TABLE
{
	int start[16];
	int length[16];
	BYTE character[16384];
	BYTE flag[16384];
};

////////////////////////////////////////////////////////////
// Structure for setting program data
////////////////////////////////////////////////////////////

struct LE_PROGRAM_ELEMENT
{
	int length;
	BYTE program_step[512][16];
};

struct LE_PROGRAM
{
	LE_PROGRAM_ELEMENT program[4];
};

////////////////////////////////////////////////////////////
// Structure for receiving monitored data
////////////////////////////////////////////////////////////

#define LE_MONSTATUS_DATA_VISIBLE	0x80

struct LE_MONDATA{
	BYTE statusSD;
	BYTE statusRD;
	BYTE SD;
	BYTE RD;
};

////////////////////////////////////////////////////////////
// Key code
////////////////////////////////////////////////////////////

#define LE_REMOTE_KEY_0          0x0000
#define LE_REMOTE_KEY_1          0x0001
#define LE_REMOTE_KEY_2          0x0002
#define LE_REMOTE_KEY_3          0x0003
#define LE_REMOTE_KEY_4          0x0004
#define LE_REMOTE_KEY_5          0x0005
#define LE_REMOTE_KEY_6          0x0006
#define LE_REMOTE_KEY_7          0x0007
#define LE_REMOTE_KEY_8          0x0008
#define LE_REMOTE_KEY_9          0x0009
#define LE_REMOTE_KEY_A          0x000a
#define LE_REMOTE_KEY_B          0x000b
#define LE_REMOTE_KEY_C          0x000c
#define LE_REMOTE_KEY_D          0x000d
#define LE_REMOTE_KEY_E          0x000e
#define LE_REMOTE_KEY_F          0x000f
#define LE_REMOTE_KEY_LEFT       0x0010
#define LE_REMOTE_KEY_RIGHT      0x0011
#define LE_REMOTE_KEY_UP         0x0012
#define LE_REMOTE_KEY_DOWN       0x0013
#define LE_REMOTE_KEY_ENTER      0x0014
#define LE_REMOTE_KEY_PAGEUP     0x0015
#define LE_REMOTE_KEY_PAGEDOWN   0x0016
#define LE_REMOTE_KEY_MENU       0x0017
#define LE_REMOTE_KEY_DISPLAY    0x0018
#define LE_REMOTE_KEY_TIMECOUNT  0x0019
#define LE_REMOTE_KEY_HEXCODE    0x001a
#define LE_REMOTE_KEY_DATACODE   0x001b
#define LE_REMOTE_KEY_ZOOM       0x001b
#define LE_REMOTE_KEY_DELETE     0x001c
#define LE_REMOTE_KEY_TOP        0x001c
#define LE_REMOTE_KEY_DONTCARE   0x001d
#define LE_REMOTE_KEY_BOTTOM     0x001d
#define LE_REMOTE_KEY_LOADSAVE   0x001e
#define LE_REMOTE_KEY_FIND       0x001f
#define LE_REMOTE_KEY_PRINT      0x0020
#define LE_REMOTE_KEY_RUN        0x0021
#define LE_REMOTE_KEY_STOP       0x0022
#define LE_REMOTE_KEY_SHIFTON    0x0023
#define LE_REMOTE_KEY_POWER      0x0030
#define LE_REMOTE_KEY_F1         0x0031
#define LE_REMOTE_KEY_F2         0x0032
#define LE_REMOTE_KEY_F3         0x0033
#define LE_REMOTE_KEY_F4         0x0034
#define LE_REMOTE_KEY_F5         0x0035

#define LE_REMOTE_KEY_SHIFT      0x0080

////////////////////////////////////////////////////////////
// Structure of setting analyzer
////////////////////////////////////////////////////////////

enum LE_FUNCTION {
	LE_FUNCTION_UNKNOWN	= -1,
	LE_FUNCTION_ONLINE	,
	LE_FUNCTION_DELAY	,
	LE_FUNCTION_TREND	,
	LE_FUNCTION_BERT	,
	LE_FUNCTION_MANUAL	,
	LE_FUNCTION_BUFFER	,
	LE_FUNCTION_PROGRAM	,
	LE_FUNCTION_FLOW	,
	LE_FUNCTION_ECHO	,
	LE_FUNCTION_POLLING	,
	LE_NOF_FUNCTION
};

enum LE_PROTCOL {
	LE_PROTCOL_UNKNOWN	= -1,
	LE_PROTCOL_ASYNC	,
	LE_PROTCOL_SYNC		,
	LE_PROTCOL_HDLC		,
	LE_PROTCOL_PPP		,
	LE_PROTCOL_IRDA		,
	LE_PROTCOL_I2C		,
	LE_PROTCOL_BURST	,
	LE_PROTCOL_CAN		,
	LE_PROTCOL_HSHDLC	,
	LE_NOF_PROTOCOL
};

enum LE_DATACODE {
	LE_DATACODE_ASCII    ,
	LE_DATACODE_EBCDIC   ,
	LE_DATACODE_EBCDIK   ,
	LE_DATACODE_JIS7     ,
	LE_DATACODE_JIS8     ,
	LE_DATACODE_HEX      ,
	LE_DATACODE_EBCD     ,
	LE_DATACODE_TRANSCODE,
	LE_DATACODE_IPARS    ,
	LE_DATACODE_BAUDOT   ,
};

enum LE_DATABIT {
	LE_DATABIT_5   ,
	LE_DATABIT_6   ,
	LE_DATABIT_7   ,
	LE_DATABIT_8   ,
};

enum LE_PARITY {
	LE_PARITY_NONE ,
	LE_PARITY_ODD  ,
	LE_PARITY_EVEN ,
	LE_PARITY_MARK ,
	LE_PARITY_SPACE,
	LE_PARITY_MP   ,
};

enum LE_STOPBIT {
	LE_STOPBIT_1 ,
	LE_STOPBIT_2 ,
};

enum LE_DATAFORMAT {
	LE_DATAFORMAT_NRZ ,
	LE_DATAFORMAT_NRZI,
	LE_DATAFORMAT_FM0 ,
	LE_DATAFORMAT_FM1 ,
};

enum LE_BCC {
	LE_BCC_NONE    ,
	LE_BCC_LRC_ODD ,
	LE_BCC_LRC_EVEN,
	LE_BCC_CRC_16  ,
	LE_BCC_CRC_ITUT,
	LE_BCC_CRC_6   ,
	LE_BCC_CRC_12  ,
};

enum LE_DATASEQUENCE {
	LE_DATASEQUENCE_LSBFIRST,
	LE_DATASEQUENCE_MSBFIRST,
};

enum LE_IFCODE {
	LE_IFCODE_UNKNOWNM,
	LE_IFCODE_UNKNOWNS,
	LE_IFCODE_OPTION  ,
	LE_IFCODE_V24     ,
	LE_IFCODE_X21     ,
	LE_IFCODE_PROBE   ,
	LE_IFCODE_RS449   ,
	LE_IFCODE_V35     ,
	LE_IFCODE_IRDA    ,
	LE_IFCODE_I2C     ,
	LE_IFCODE_BURST   ,
	LE_IFCODE_RS530   ,
	LE_IFCODE_CAN     = 32,
};

enum LE_IDLERECORD {
	LE_IDLERECORD_OFF  ,
	LE_IDLERECORD_100ms,
	LE_IDLERECORD_10ms ,
	LE_IDLERECORD_1ms  ,
};

enum LE_TMSPRECORD {
	LE_TMSPRECORD_OFF   ,
	LE_TMSPRECORD_DHM   ,
	LE_TMSPRECORD_HMS   ,
	LE_TMSPRECORD_MS10ms,
};

enum LE_IFCLOCK {
	LE_CLOCK_ST1,
	LE_CLOCK_ST2,
	LE_CLOCK_RT ,
	LE_CLOCK_AR ,
};

enum LE_FCS {
	LE_FCS_NONE,
	LE_FCS_16  ,
	LE_FCS_32  ,
};

enum LE_IDLEMODE {
	LE_IDLEMODE_MARK,
	LE_IDLEMODE_FLAG,
};

enum LE_HDLCFRAME {
	LE_HDLCFRAME_NONE = -1,
	LE_HDLCFRAME_SDLC ,
	LE_HDLCFRAME_SDLCX,
	LE_HDLCFRAME_X25  ,
	LE_HDLCFRAME_X25X ,
	LE_HDLCFRAME_LAPD ,
};

enum LE_HDLCPACKET {
	LE_HDLCPACKET_NONE = -1,
	LE_HDLCPACKET_X25 ,
	LE_HDLCPACKET_LAPD,
};

enum LE_I2CSIM {
	LE_I2CSIM_SLAVE ,
	LE_I2CSIM_MASTER,
};

////////////////////////////////////////////////////////////

struct LE_CONFIG_ASYNC
{
    long SpeedSd;                    // SD speed: 10 times more than actual bps.
    long SpeedRd;                    // RD speed: 10 times more than actual bps.
    LE_DATACODE DataCode;            // data code: LE_DATACODE (fixed or multiple number)
    LE_DATABIT DataBit;              // number of data bit: LE_DATABIT (fixed or multiple number)
    LE_PARITY Parity;                // parity check: LE_PARITY (fixed or multiple number)
    LE_STOPBIT StopBit;              // number of stop bit: LE_STOPBIT (fixed or multiple number)
    LE_DATAFORMAT DataFormat;        // data format: LE_DATAFORMAT (fixed or multiple number)
    unsigned char FrmEndCharCount;   // Number of frame end character
    char FrmEndChar;                 // Frame end character
    char FrmEndTime;                 // Time of receiving frame end
    LE_BCC Bcc;                      // BCC LE_BCC (fixed or multiple number)
    unsigned char BeginCharCount;    // Number of BCC begin character
    char BeginChar1;                 // BCC begin character
    char BeginChar2;                 // 
    unsigned char EndCharCount;      // Number of BCC end character
    char EndChar1;                   // BCC end character
    char EndChar2;                   // 
    unsigned char ItbCharCount;      // Number of ITB character
    char ItbChar;                    // ITB character
    char Transparent;                // Transparent
    char DleChar;                    // DLE character
    LE_DATASEQUENCE Sequence;        // Sequence: LE_DATASEQUENCE (fixed or multiple number)
};

struct LE_CONFIG_SYNC
{
    long SpeedSd;                    // SD speed: 10 times more than actual bps.
    long SpeedRd;                    // RD speed: 10 times more than actual bps.
    LE_DATACODE DataCode;            // data code: LE_DATACODE (fixed or multiple number)
    LE_DATABIT DataBit;              // number of data bit: LE_DATABIT (fixed or multiple number)
    LE_PARITY Parity;                // parity check: LE_PARITY (fixed or multiple number)
    LE_IFCLOCK Clock;                // clock selection: LE_CLOCK (fixed or multiple number)
    LE_DATAFORMAT DataFormat;        // data format: LE_DATAFORMAT (fixed or multiple number)
    unsigned char SynCharCount;      // Number of Sync character
    char SynChar1;                   // Sync character
    char SynChar2;                   // 
    char RstChar;                    // Sync Reset character
    unsigned char RstRepeat;         // Sync Reset character repeat
    unsigned char SuppressCharCount; // Number of suppress character
    char SuppressChar;               // Suppress character
    LE_BCC Bcc;                      // BCC LE_BCC (fixed or multiple number)
    unsigned char BeginCharCount;    // Number of BCC begin character
    char BeginChar1;                 // BCC begin character
    char BeginChar2;                 // 
    unsigned char EndCharCount;      // Number of BCC end character
    char EndChar1;                   // BCC end character
    char EndChar2;                   // 
    unsigned char ItbCharCount;      // Number of ITB character
    char ItbChar;                    // ITB character
    char Transparent;                // Transparent
    char DleChar;                    // DLE character
    LE_DATASEQUENCE Sequence;        // Sequence: LE_DATASEQUENCE (fixed or multiple number)
};

struct LE_CONFIG_HDLC
{
    long SpeedSd;                    // SD speed: 10 times more than actual bps.
    long SpeedRd;                    // RD speed: 10 times more than actual bps.
    LE_DATACODE DataCode;            // data code:  LE_DATACODE (fixed or multiple number)
    LE_IFCLOCK Clock;                // clock selection: LE_CLOCK (fixed or multiple number)
    LE_DATAFORMAT DataFormat;        // data format: LE_DATAFORMAT (fixed or multiple number)
    LE_FCS Fcs;                      // FCS LE_FCS (fixed or multiple number)
    char fFilterSd;                  // SD monitor addres filter
    char FilterSdAddr;               // SD monitor frame address
    char fFilterRd;                  // RD monitor address filer
    char FilterRdAddr;               // RD monitor frame address
    LE_IDLEMODE IdleMode;            // Idle mode: LE_IDLEMODE (fixed or multiple number)
    char LeadingCount;               // number of leading flag
    LE_HDLCFRAME FrameProtocol;      // Frame translation protocol: LE_HDLCFRAME (fixed or multiple number)
    LE_HDLCPACKET PacketProtocol;    // Packet translation protocol: LE_HDLCPACKET (fixed or multiple number)
};

struct LE_CONFIG_PPP
{
    long SpeedSd;                    // SD speed: 10 times more than actual bps.
    long SpeedRd;                    // RD speed: 10 times more than actual bps.
    LE_DATACODE DataCode;            // data code:  LE_DATACODE (fixed or multiple number)
    char Suppress;                   // Flag character suppress
    LE_FCS Fcs;                      // FCS LE_FCS (fixed or multiple number)
};

struct LE_CONFIG_IRDA
{
    long Speed;                      // Transferring speed is 10 times more than actual bps.
    LE_DATACODE DataCode;            // data code  LE_DATACODE (fixed or multiple number)
    char Suppress;                   // Flag character suppress
};

struct LE_CONFIG_I2C
{
    long Speed;                      // Transferring speed is 10 times more than actual bps.
    LE_DATACODE DataCode;            // data code  LE_DATACODE (fixed or multiple number)
    LE_I2CSIM I2cSim;                // I2C Simulation mode LE_I2CSIM (fixed or multiple number)
    char f10BitAddr;                 // 10 bit address
    short SlaveAddr;                 // Slave address
};

struct LE_CONFIG_BURST
{
    LE_DATACODE DataCode;            // data code  LE_DATACODE (fixed or multiple number)
    LE_DATABIT DataBit;              // number of data bit: LE_DATABIT (fixed or multiple number)
    LE_PARITY Parity;                // Parity check: LE_PARITY (fixed or multiple number)
    unsigned char FrmEndCharCount;   // Frame end character count
    char FrmEndChar;                 // Frame end character
    char FrmEndTime;                 // Frame end time
    LE_DATASEQUENCE Sequence;        // Sequence LE_DATASEQUENCE (fixed or multiple number)
};

////////////////////////////////////////////////////////////

enum LE_AUTOCONFIG {
	LE_AUTOCONFIG_STOP,
	LE_AUTOCONFIG_RUN ,
};

////////////////////////////////////////////////////////////

struct LE_ONLINESETUP
{
    LE_AUTOCONFIG AutoConfig;  // Set Auto-Configuration.
};

struct LE_MANUALSETUP
{
    unsigned long Delay;       // Set the transmission interval between characters in msec.
    unsigned long Idle;        // Set the interval of data transmission repeatedly in msec.
    char Repeat;               // Set whether using the repeat mode or not.
};

struct LE_PROGRAMSETUP
{
    unsigned char No;          // Set which program to use in the Program mode.
};

////////////////////////////////////////////////////////////

struct LE_SETUP
{
	LE_FUNCTION Func;
	LE_PROTCOL Protocol;
	LE_IDLERECORD Idle;
	LE_TMSPRECORD Tmsp;
	LE_CONFIG_ASYNC Async;
	LE_CONFIG_SYNC Sync;
	LE_CONFIG_HDLC Hdlc;
	LE_CONFIG_PPP Ppp;
	LE_CONFIG_IRDA Irda;
	LE_CONFIG_I2C I2c;
	LE_CONFIG_BURST Burst;
	LE_ONLINESETUP Online;
	LE_MANUALSETUP Manual;
	LE_PROGRAMSETUP Program;
};

////////////////////////////////////////////////////////////
// Function
////////////////////////////////////////////////////////////

DECLSPEC LEGetDllVersion(WORD *version);

DECLSPEC LEConnect(char *com);
DECLSPEC LEDisconnect();
DECLSPEC LEStartMeasure();
DECLSPEC LEStopMeasure();
DECLSPEC LEEmulationKey(DWORD code);
	
DECLSPEC LEGetSetup(LE_SETUP *setup);
DECLSPEC LESetSetup(LE_SETUP *setup);
DECLSPEC LEGetTable(LE_TABLE *table);
DECLSPEC LESetTable(LE_TABLE *table);
DECLSPEC LEGetTableElement(LE_TABLE_ELEMENT *tableelem, int number);
DECLSPEC LESetTableElement(LE_TABLE_ELEMENT *tableelem, int number);
DECLSPEC LEGetProgram(LE_PROGRAM *program);
DECLSPEC LESetProgram(LE_PROGRAM *program);
DECLSPEC LEGetProgramElement(LE_PROGRAM_ELEMENT *programelem, DWORD number);
DECLSPEC LESetProgramElement(LE_PROGRAM_ELEMENT *programelem, DWORD number);

DECLSPEC LEGetMonitorData(LE_MONDATA *mondata, DWORD *length);
DECLSPEC LEGetMonitorDataOffset(LE_MONDATA *mondata, DWORD *length, DWORD offset);
